#
# matmult-fishing.R, 27 Apr 25
#
# Data from:
# Understanding the Impact of Input Entropy on FPU, CPU, and GPU Power
# Sridutt Bhalachandra, Brian Austin, Samuel Williams, and Nicholas J. Wright

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+") 
pal_col=rainbow(2)


extract_power=function(file_str)
{
pfix=read.csv(file_str)

pfix$secs=as.POSIXct(pfix$timestamp, format="%Y/%m/%d %H:%M:%S")
pfix$elapsed=as.numeric(pfix$secs-pfix$secs[1])

pfix=subset(pfix, index == 0) # This is the subset used in their code

# Mean within a bin of a second
elapsed_mean=ddply(pfix, .(elapsed), function(df) mean(df$power.draw..W.))
}


pfix=extract_power("pm_gpu_fixed_dgemm_16384_100_power_1_nid001677.csv")
prand=extract_power("pm_gpu_random_dgemm_16384_100_power_1_nid001677.csv")

plot(pfix$elapsed, pfix$V1, col=pal_col[2], type="b", cex=1.3,
	xaxs="i", yaxs="i",
	xlim=c(0, 60), ylim=c(0, 410),
	xlab="Elapsed time (seconds)", ylab="Power (Watts)")

lines(prand$elapsed, prand$V1, col=pal_col[1], type="b", cex=1.3)

legend("bottom", legend=c("Random values", "Same value"), cex=1.2,
                        fill=pal_col, border="white", bty="n")


dev.copy(dev=png, file="matmult-ent-power.png")
dev.off()

